#[derive(ArrayDefaults)]Expand description
Macro to create a standard [Self; N] implementation of ot_tools_io::DefaultsArray on a type,
i.e. a standard array filled with an inferred volume of defaults instances based on type hints
#[derive(ArrayDefaults)]Macro to create a standard [Self; N] implementation of ot_tools_io::DefaultsArray on a type,
i.e. a standard array filled with an inferred volume of defaults instances based on type hints