BoxedArrayDefaults

Derive Macro BoxedArrayDefaults 

#[derive(BoxedArrayDefaults)]
Macro to create a standard Box<serde_big_array::Array<Self, N>> implementation of ot_tools_io::DefaultsArray on a type, i.e. a non-standard array filled with an inferred volume of defaults instances based on type hints Requires an existing implementation of Defaults<[Self; N]> on the type.