#[derive(ContainerArrayMethods)]Expand description
Adds a bunch of boilerplate methods for a new array container type.
WARNING: This is fragile and relies on string interpolation of the type name.
#[derive(ContainerArrayMethods)]Adds a bunch of boilerplate methods for a new array container type.
WARNING: This is fragile and relies on string interpolation of the type name.